==> zio-aws-macie2_2.12-5.17.126.1-sources.jar: zio/aws/macie2/model/AdminAccount.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class AdminAccount(
    accountId: Option[__string] = None,
    status: Option[zio.aws.macie2.model.AdminStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.AdminAccount = {
    import AdminAccount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.AdminAccount
      .builder()
      .optionallyWith(
        accountId.map(value => __string.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.AdminAccount.ReadOnly =
    zio.aws.macie2.model.AdminAccount.wrap(buildAwsValue())
}
object AdminAccount {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.AdminAccount
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.AdminAccount = zio.aws.macie2.model
      .AdminAccount(accountId.map(value => value), status.map(value => value))
    def accountId: Option[__string]
    def status: Option[zio.aws.macie2.model.AdminStatus]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getStatus: ZIO[Any, AwsError, zio.aws.macie2.model.AdminStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.AdminAccount
  ) extends zio.aws.macie2.model.AdminAccount.ReadOnly {
    override val accountId: Option[__string] = scala
      .Option(impl.accountId())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val status: Option[zio.aws.macie2.model.AdminStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.macie2.model.AdminStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.AdminAccount
  ): zio.aws.macie2.model.AdminAccount.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.150.1-sources.jar: zio/aws/macie2/model/AdminAccount.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class AdminAccount(
    accountId: Option[__string] = None,
    status: Option[zio.aws.macie2.model.AdminStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.AdminAccount = {
    import AdminAccount.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.AdminAccount
      .builder()
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(status.map(value => value.unwrap))(_.status)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.AdminAccount.ReadOnly =
    zio.aws.macie2.model.AdminAccount.wrap(buildAwsValue())
}
object AdminAccount {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.AdminAccount
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.AdminAccount = zio.aws.macie2.model
      .AdminAccount(accountId.map(value => value), status.map(value => value))
    def accountId: Option[__string]
    def status: Option[zio.aws.macie2.model.AdminStatus]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getStatus: ZIO[Any, AwsError, zio.aws.macie2.model.AdminStatus] =
      AwsError.unwrapOptionField("status", status)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.AdminAccount
  ) extends zio.aws.macie2.model.AdminAccount.ReadOnly {
    override val accountId: Option[__string] =
      scala.Option(impl.accountId()).map(value => value: __string)
    override val status: Option[zio.aws.macie2.model.AdminStatus] = scala
      .Option(impl.status())
      .map(value => zio.aws.macie2.model.AdminStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.AdminAccount
  ): zio.aws.macie2.model.AdminAccount.ReadOnly = new Wrapper(impl)
}
